"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Store = exports.globFiles = void 0;
const eventemitter3_1 = require("eventemitter3");
const debug_1 = __importDefault(require("debug"));
const confidence_1 = require("@makeomatic/confidence");
const node_assert_1 = require("node:assert");
const load_config_1 = require("./load-config");
const debug = (0, debug_1.default)('ms-conf');
var load_config_2 = require("./load-config");
Object.defineProperty(exports, "globFiles", { enumerable: true, get: function () { return load_config_2.globFiles; } });
class Store extends eventemitter3_1.EventEmitter {
    opts;
    store;
    _prepend;
    _append;
    constructor({ crashOnError = true, defaultOpts = {} } = {}) {
        super();
        this.opts = {
            crashOnError,
            defaultOpts
        };
        this.reload = this.reload.bind(this);
    }
    /**
     * Add base configuration
     */
    prependDefaultConfiguration(baseConfig) {
        (0, node_assert_1.strict)(baseConfig, 'must be a path to specific location');
        (0, node_assert_1.strict)(typeof baseConfig === 'string');
        this._prepend = baseConfig;
    }
    /**
     * Appends passed configuration to resolved config
     */
    append(configuration) {
        this._append = configuration;
    }
    /**
     * Triggers reload from the disk
     */
    async reload() {
        debug('reloading configuration');
        this.store = new confidence_1.Store(await (0, load_config_1.loadConfiguration)(this.opts.crashOnError, this._prepend, this._append));
        this.emit('reload');
    }
    /**
     * alias for reload for now
     */
    async ready() {
        await this.reload();
    }
    enableReload() {
        debug('enabling sigusr');
        process.on('SIGUSR1', this.reload);
        process.on('SIGUSR2', this.reload);
    }
    disableReload() {
        debug('disabling sigusr');
        process.removeListener('SIGUSR1', this.reload);
        process.removeListener('SIGUSR2', this.reload);
    }
    get(key, opts = this.opts.defaultOpts) {
        (0, node_assert_1.strict)(this.store, 'call await store.ready() before accessing config');
        return this.store.get(key, opts);
    }
    meta(key, opts = this.opts.defaultOpts) {
        (0, node_assert_1.strict)(this.store, 'call await store.ready() before accessing config');
        return this.store.meta(key, opts);
    }
}
exports.Store = Store;
//# sourceMappingURL=index.js.map